@@ -374,6 +374,33 @@ class ParserTest(_ParserTestBase):
 
       x: somewhere.Foo""")
 
+  def test_external_alias(self):
+    self.check("""
+      from somewhere import Foo
+
+      class Bar:
+          Baz = Foo
+    """, """
+      from typing import Any
+
+      from somewhere import Foo
+
+      class Bar:
+          Baz: Any
+    """)
+
+  def test_same_named_alias(self):
+    self.check("""
+      import somewhere
+      class Bar:
+          Foo = somewhere.Foo
+    """, """
+      from typing import Any
+
+      class Bar:
+          Foo: Any
+    """)
+
   def test_type_params(self):
     ast = self.check("""
       from typing import TypeVar
@@ -1019,6 +1046,26 @@ class FunctionTest(_ParserTestBase):
       def f(x: int) -> None: ...
     """)
 
+  def test_typeignore_alias(self):
+    self.check("""
+      class Foo:
+          def f(self) -> None: ...
+          g = f  # type: ignore
+    """, """
+      class Foo:
+          def f(self) -> None: ...
+          def g(self) -> None: ...
+    """)
+
+  def test_typeignore_slots(self):
+    self.check("""
+      class Foo:
+          __slots__ = ["a", "b"]  # type: ignore
+    """, """
+      class Foo:
+          __slots__ = ["a", "b"]
+    """)
+
   def test_decorators(self):
     # These tests are a bit questionable because most of the decorators only
     # make sense for methods of classes.  But this at least gives us some
@@ -1134,6 +1181,13 @@ class FunctionTest(_ParserTestBase):
       class Foo: ...
     """, "class Foo: ...")
 
+  def test_decorated_class(self):
+    self.check("""
+      @dataclass
+      class Foo: ...
+    """)
+
+  @unittest.skip("Decorator work in progress b/159641684")
   def test_bad_decorated_class(self):
     self.check_error("""
       @classmethod
@@ -1261,31 +1315,6 @@ class ClassTest(_ParserTestBase):
       class Foo(metaclass=Meta, Bar): ...
       """, 1, "non-keyword arguments cannot follow keyword arguments")
 
-  def test_typed_dict_kwarg(self):
-    self.check("""
-      from typing import TypedDict
-
-      class Foo(TypedDict, total=False): ...
-    """, """
-      from typing import TypedDict
-
-      class Foo(TypedDict): ...
-    """)
-    self.check_error("""
-      class Foo(object, total=False): ...
-    """, 1, "'total' allowed as classdef kwarg only for TypedDict subclasses")
-
-  def test_multiple_classdef_kwargs(self):
-    self.check("""
-      from typing import TypedDict
-
-      class Foo(TypedDict, total=False, metaclass=Meta): ...
-    """, """
-      from typing import TypedDict
-
-      class Foo(TypedDict, metaclass=Meta): ...
-    """)
-
   def test_shadow_pep484(self):
     self.check("""
       class List:
@@ -1637,13 +1666,6 @@ class ClassIfTest(_ParserTestBase):
           import foo
     """, 3, "syntax error")
 
-  def test_bad_alias(self):
-    self.check_error("""
-      class Foo:
-        if sys.version_info > (3, 4, 0):
-          a = b
-    """, 1, "Illegal value for alias 'a'")
-
   def test_no_class(self):
     self.check("""
       class Foo:
@@ -2408,5 +2430,93 @@ class LiteralTest(_ParserTestBase):
     """)
 
 
+class TypedDictTest(_ParserTestBase):
+
+  def test_assign(self):
+    self.check("""
+      from typing_extensions import TypedDict
+      X = TypedDict('X', {})
+    """, """
+      from typing import Any, Dict
+
+      from typing_extensions import TypedDict
+      X = Dict[str, Any]
+    """)
+
+  def test_assign_with_items(self):
+    self.check("""
+      from typing_extensions import TypedDict
+      X = TypedDict('X', {'a': int, 'b': str})
+    """, """
+      from typing import Any, Dict
+
+      from typing_extensions import TypedDict
+      X = Dict[str, Any]
+    """)
+
+  def test_assign_with_kwarg(self):
+    self.check("""
+      from typing_extensions import TypedDict
+      X = TypedDict('X', {}, total=False)
+    """, """
+      from typing import Any, Dict
+
+      from typing_extensions import TypedDict
+      X = Dict[str, Any]
+    """)
+
+  def test_trailing_comma(self):
+    self.check("""
+      from typing_extensions import TypedDict
+      X = TypedDict('X', {
+          'a': int,
+          'b': str,
+      },)
+    """, """
+      from typing import Any, Dict
+
+      from typing_extensions import TypedDict
+      X = Dict[str, Any]
+    """)
+
+  def test_kwarg(self):
+    self.check("""
+      from typing import TypedDict
+
+      class Foo(TypedDict, total=False): ...
+    """, """
+      from typing import TypedDict
+
+      class Foo(TypedDict): ...
+    """)
+    self.check_error("""
+      class Foo(object, total=False): ...
+    """, 1, "'total' allowed as classdef kwarg only for TypedDict subclasses")
+
+  def test_typing_extensions(self):
+    self.check("""
+      from typing_extensions import TypedDict
+
+      class Foo(TypedDict, total=False): ...
+    """, """
+      import typing_extensions
+
+      from typing_extensions import TypedDict
+
+      class Foo(typing_extensions.TypedDict): ...
+    """)
+
+  def test_multiple_classdef_kwargs(self):
+    self.check("""
+      from typing import TypedDict
+
+      class Foo(TypedDict, total=False, metaclass=Meta): ...
+    """, """
+      from typing import TypedDict
+
+      class Foo(TypedDict, metaclass=Meta): ...
+    """)
+
+
 if __name__ == "__main__":
   unittest.main()
