@@ -334,10 +334,10 @@ class TestOptimize(parser_test_base.ParserTest):
     src = textwrap.dedent("""
         def foo(a: int) -> int or float
         def bar(a: str) -> str
-        def foo(a: int) -> str or unicode
+        def foo(a: int) -> str or bytes
     """)
     new_src = textwrap.dedent("""
-        def foo(a: int) -> int or float or str or unicode
+        def foo(a: int) -> int or float or str or bytes
         def bar(a: str) -> str
     """)
     self.AssertOptimizeEquals(src, new_src)
@@ -774,147 +774,6 @@ class TestOptimize(parser_test_base.ParserTest):
             def f(self) -> float: ...
     """).lstrip())
 
-  def test_remove_inherited_methods_with_late_type(self):
-    src = textwrap.dedent("""
-        class Foo(other.Bar):
-          def bar() -> float
-    """)
-    expected = textwrap.dedent("""
-        class Foo(other.Bar):
-          def bar() -> float
-    """)
-    ast = self.Parse(src)
-    ast = ast.Visit(visitors.ReplaceTypes(
-        {"other.Bar": pytd.LateType("other.Bar")}))
-    ast = ast.Visit(optimize.RemoveInheritedMethods())
-    ast = ast.Visit(visitors.LateTypeToClassType())
-    self.AssertSourceEquals(ast, expected)
-
-  def test_remove_inherited_methods_without_self(self):
-    src = textwrap.dedent("""
-        class Bar(object):
-          def baz(self) -> int
-
-        class Foo(Bar):
-          def baz(self) -> int
-          def bar() -> float
-    """)
-    expected = textwrap.dedent("""
-        class Bar(object):
-          def baz(self) -> int
-
-        class Foo(Bar):
-          def bar() -> float
-    """)
-    ast = self.Parse(src)
-    ast = visitors.LookupClasses(ast, self.builtins)
-    ast = ast.Visit(optimize.RemoveInheritedMethods())
-    self.AssertSourceEquals(ast, expected)
-
-  def test_remove_inherited_methods(self):
-    src = textwrap.dedent("""
-        class A():
-            def f(self, y: int) -> bool
-            def g(self) -> float
-
-        class B(A):
-            def b(self) -> B
-            def f(self, y: int) -> bool
-
-        class C(A):
-            def c(self) -> C
-            def f(self, y: int) -> bool
-
-        class D(B):
-            def g(self) -> float
-            def d(self) -> D
-    """)
-    expected = textwrap.dedent("""
-        class A():
-            def f(self, y: int) -> bool
-            def g(self) -> float
-
-        class B(A):
-            def b(self) -> B
-
-        class C(A):
-            def c(self) -> C
-
-        class D(B):
-            def d(self) -> D
-    """)
-    ast = self.Parse(src)
-    ast = visitors.LookupClasses(ast, self.builtins)
-    ast = ast.Visit(optimize.RemoveInheritedMethods())
-    self.AssertSourceEquals(ast, expected)
-
-  def test_remove_inherited_methods_with_override(self):
-    src = textwrap.dedent("""
-        class A(object):
-            def f(self, x) -> ?
-        class B(A):
-            def f(self) -> ?
-        class C(B):
-            def f(self) -> ?
-        class D(B):
-            def f(self, x) -> ?
-    """)
-    expected = textwrap.dedent("""
-        class A(object):
-            def f(self, x) -> ?
-        class B(A):
-            def f(self) -> ?
-        class C(B):
-            pass
-        class D(B):
-            def f(self, x) -> ?
-    """)
-    ast = self.Parse(src)
-    ast = visitors.LookupClasses(ast, self.builtins)
-    ast = ast.Visit(optimize.RemoveInheritedMethods())
-    self.AssertSourceEquals(ast, expected)
-
-  def test_remove_inherited_methods_with_diamond(self):
-    src = textwrap.dedent("""
-        class A(object):
-            def f(self, x) -> ?
-        class B(A):
-            pass
-        class C(A):
-            def f(self, x, y) -> ?
-        class D(B, C):
-            def f(self, x) -> ?
-    """)
-    ast = self.Parse(src)
-    ast = visitors.LookupClasses(ast, self.builtins)
-    ast = ast.Visit(optimize.RemoveInheritedMethods())
-    self.AssertSourceEquals(ast, src)
-
-  def test_remove_inherited_methods_with_circle(self):
-    src = textwrap.dedent("""
-        class A(B):
-            def f(self) -> ?
-        class B(A):
-            def f(self) -> ?
-    """)
-    ast = self.Parse(src)
-    ast = visitors.LookupClasses(ast, self.builtins)
-    ast = ast.Visit(optimize.RemoveInheritedMethods())
-    self.AssertSourceEquals(ast, src)
-
-  def test_dont_remove_abstract_method_implementation(self):
-    src = textwrap.dedent("""
-      class A(object):
-        @abstractmethod
-        def foo(self): ...
-      class B(A):
-        def foo(self): ...
-    """)
-    ast = self.Parse(src)
-    ast = visitors.LookupClasses(ast, self.builtins)
-    ast = ast.Visit(optimize.RemoveInheritedMethods())
-    self.AssertSourceEquals(ast, src)
-
   def test_absorb_mutable_parameters(self):
     src = textwrap.dedent("""
         def popall(x: list[?]) -> ?:
